@@ -45,11 +45,9 @@ def next(oid):
 @app.route('/query')
 def query():
     start = int(request.args.get('pms_js_time')) /1000
-    print start
     start = datetime.datetime.utcfromtimestamp(start)
     #start -= datetime.timedelta(hours=4)
     end = start + datetime.timedelta(hours=1)
-    print start
 
     start_id = ObjectId.from_datetime(start)
     end_id = ObjectId.from_datetime(end)
@@ -81,6 +79,8 @@ def last_data(name, ly, hours):
     start = datetime.datetime(*timetuple)
     interval = datetime.timedelta(hours=1)
 
+    minute_offset = (-(time.altzone if time.daylight else time.timezone)) / 60
+
     query = {
         'name': name,
         'date.year': {'$gte': start.year},
@@ -105,7 +105,7 @@ def last_data(name, ly, hours):
             label_data,
             empty_set
         )
-        local_data_list = map_dataset_to_local_time(data_list)
+        local_data_list = map_dataset_to_local_time(data_list, minute_offset)
         js_data_list = map_data_set_to_javascript_times(local_data_list)
         flot_data.append({
             'label': label,
@@ -211,14 +211,14 @@ def map_data_set_to_javascript_times(data):
     return new_data
 
 
-def map_dataset_to_local_time(data):
+def map_dataset_to_local_time(data, minute_offset):
     """Takes a list of tuples and returns a list of tuples with the first
     element adjusted from GMT to the current TZ.
 
     """
     new_data = []
     for (timestamp, datum) in data:
-        local_timestamp = timestamp - datetime.timedelta(hours=4)
+        local_timestamp = timestamp + datetime.timedelta(minutes=minute_offset)
         new_data.append((local_timestamp, datum))
     return new_data
 
